@@ -123,6 +123,16 @@ class BaremetalScenarioTest(manager.ScenarioTest):
         ironic_waiters.wait_node_instance_association(self.baremetal_client,
                                                       instance_id)
 
+    @classmethod
+    def wait_for_agent_heartbeat(cls, node_id, timeout=None):
+        ironic_waiters.wait_node_value_in_field(
+            cls.baremetal_client,
+            node_id=node_id,
+            field='driver_internal_info',
+            value='agent_last_heartbeat',
+            timeout=timeout or CONF.baremetal.deploywait_timeout,
+            interval=10)
+
     @classmethod
     def get_node(cls, node_id=None, instance_id=None, api_version=None):
         return utils.get_node(cls.baremetal_client, node_id, instance_id,
@@ -261,7 +271,8 @@ class BaremetalScenarioTest(manager.ScenarioTest):
             password=rescue_password,
             server=self.instance,
             servers_client=servers_client,
-            ssh_timeout=CONF.baremetal.rescue_timeout)
+            ssh_timeout=CONF.baremetal.rescue_timeout,
+            ssh_allow_agent=False)
         linux_client.validate_authentication()
 
     def unrescue_instance(self, instance, node, server_ip,
